@@ -115,17 +115,22 @@ static struct poptOption bonobo_ui_gtk_options [] = {
 	{ "gdk-no-debug", '\0', POPT_ARG_STRING, NULL, 0,
 	  N_("Gdk debugging flags to unset"), N_("FLAGS")},
 
-	  /* X11 only */
+	/* X11 only */
 	{ "display", '\0', POPT_ARG_STRING, NULL, 0,
 	  N_("X display to use"), N_("DISPLAY")},
 
-	  /* X11 only */
+#ifdef HAVE_GDK_SCREEN_GET_NUMBER
+	/* X11 & multi-head only */
+	{ "screen", '\0', POPT_ARG_STRING, NULL, 0,
+	  N_("X screen to use"), N_("SCREEN")},
+#endif
+	/* X11 only */
 	{ "sync", '\0', POPT_ARG_NONE, NULL, 0,
 	  N_("Make X calls synchronous"), NULL},
 
-	  /* FIXME: this doesn't seem to exist */
+	/* FIXME: this doesn't seem to exist */
 #if 0
-	  /* X11 only */
+	/* X11 only */
 	{ "no-xshm", '\0', POPT_ARG_NONE, NULL, 0,
 	  N_("Don't use X shared memory extension"), NULL},
 #endif
@@ -136,15 +141,15 @@ static struct poptOption bonobo_ui_gtk_options [] = {
 	{ "class", '\0', POPT_ARG_STRING, NULL, 0,
 	  N_("Program class as used by the window manager"), N_("CLASS")},
 
-	  /* X11 only */
+	/* X11 only */
 	{ "gxid-host", '\0', POPT_ARG_STRING, NULL, 0,
 	  NULL, N_("HOST")},
 
-	  /* X11 only */
+	/* X11 only */
 	{ "gxid-port", '\0', POPT_ARG_STRING, NULL, 0,
 	  NULL, N_("PORT")},
 
-	  /* FIXME: this doesn't seem to exist */
+	/* FIXME: this doesn't seem to exist */
 #if 0
 	{ "xim-preedit", '\0', POPT_ARG_STRING, NULL, 0,
 	  NULL, N_("STYLE")},
