@@ -26,7 +26,8 @@ G_BEGIN_DECLS
 typedef enum {
 	BONOBO_UI_TOOLBAR_STYLE_PRIORITY_TEXT,
 	BONOBO_UI_TOOLBAR_STYLE_ICONS_AND_TEXT,
-	BONOBO_UI_TOOLBAR_STYLE_ICONS_ONLY
+	BONOBO_UI_TOOLBAR_STYLE_ICONS_ONLY,
+	BONOBO_UI_TOOLBAR_STYLE_TEXT_ONLY
 } BonoboUIToolbarStyle;
 
 typedef struct _BonoboUIToolbarPrivate BonoboUIToolbarPrivate;
